@@ -7,7 +7,7 @@ class CronUpdater():
     def generate_cron_schedule(self):
       import ConfigParser
       config = ConfigParser.ConfigParser()
-      config.read("/etc/mythbuntu-bare/mythbuntu-bare-client.conf")
+      config.read("/etc/default/mythbuntu-bare-client.conf")
       managed = config.get("General", "managed")
       schedule = config.get("Backup", "schedule")
       day = config.get("Backup", "day")
@@ -16,7 +16,7 @@ class CronUpdater():
       weekday = config.get("Backup", "weekday")
       f = open("/etc/cron.d/mythbuntu-bare","w")
       if not schedule == "disabled":
-        f.write(minute+" "+hour+" "+day+" "+"*"+" "+weekday+" root /usr/share/mythbuntu-bare/backup-task.py\n")
+          f.write(minute+" "+hour+" "+day+" "+"*"+" "+weekday+" root /usr/share/mythbuntu-bare/backup-task.py\n")
       if managed == True:
-        f.write("41 * * * * root /usr/share/mythbuntu-bare/update-task.py\n")
+          f.write("41 * * * * root /usr/share/mythbuntu-bare/update-task.py\n")
       f.close()
