@@ -22,7 +22,6 @@
 
 import string
 import subprocess
-from NvidiaDetector.nvidiadetector import NvidiaDetection
 
 ####################
 # Type dictionaries: different installation types possible
@@ -52,12 +51,12 @@ def get_frontend_plugin_dictionary(self):
     list = {
         "mytharchive": self.mytharchive_checkbox,                              \
         "mythbrowser": self.mythbrowser_checkbox,                              \
-        "mythflix": self.mythflix_checkbox,                                    \
         "mythgame": self.mythgame_checkbox,                                    \
         "mythgallery": self.mythgallery_checkbox,                              \
         "mythmusic": self.mythmusic_checkbox,                                  \
         "mythmovies": self.mythmovies_checkbox,                                \
         "mythnews": self.mythnews_checkbox,                                    \
+        "mythnetvision": self.mythnetvision_checkbox,                          \
         "mythvideo": self.mythvideo_checkbox,                                  \
         "mythweather": self.mythweather_checkbox }
     return list
@@ -91,11 +90,8 @@ def get_media_app_dictionary(self):
 
 def get_nonfree_dictionary(self):
     list = {
-        "medibuntu-keyring": self.medibuntu_keyring,                           \
-        "libdvdcss2": self.enable_libdvdcss2,                                  \
-        "ffmpeg": self.enable_ffmpeg,                                          \
-        "w64codecs": self.enable_w64codecs,                                    \
-        "w32codecs": self.enable_w32codecs }
+#        "medibuntu-keyring": self.medibuntu_keyring,                           \
+        "libdvdcss2": self.enable_libdvdcss2 }
     return list
 
 def get_services_dictionary(self,sql_object=None):
@@ -116,8 +112,7 @@ def get_diskless_dictionary(self):
 def get_artwork_dictionary(self):
     list = {
         "mythbuntu-gdm-theme": self.gdm_theme,                                 \
-        "mythbuntu-default-settings": self.xfce_theme,                         \
-        "mythbuntu-artwork-usplash": self.splash_theme }
+        "mythbuntu-default-settings": self.xfce_theme }
     return list
 
 def get_graphics_dictionary():
@@ -130,6 +125,11 @@ def get_graphics_dictionary():
             break
 
     #NVIDIA Graphics detection
+    try:
+        from NvidiaDetector.nvidiadetector import NvidiaDetection
+    except ImportError:
+        return list
+
     nv = NvidiaDetection().selectDriver()
     if nv is not None:
         list["NVIDIA Graphics"]=nv
