@@ -40,7 +40,7 @@ class MythbuntuBaRePlugin(MCCPlugin):
     #
     #Load GUI & Calculate Changes
     #
-    CONFIGFILE = "/etc/mythbuntu-bare/mythbuntu-bare-client.conf"
+    CONFIGFILE = "/etc/default/mythbuntu-bare-client.conf"
 
     USER=os.getenv("HOME")
 
@@ -77,36 +77,35 @@ class MythbuntuBaRePlugin(MCCPlugin):
         import os
         self.changes = {}
         try:
-          self.config.read(self.CONFIGFILE)
-          self.changes['serverip'] = self.config.get("General", "serverip")
-          self.changes['managed'] = self.config.get("General", "managed")
-          if str.lower(self.changes['managed']) == "true":
-            self.managed_label.set_text("This machine is current in managed mode")
-            self.radio_convert.set_sensitive(False)
-            self.backup_schedule.set_sensitive(False)
-          self.changes['BackupLocation'] = self.config.get("Backup", "storagedir")
-          self.changes['backup_db'] = self.config.get("Backup", "db")
-          self.changes['backup_schedule'] = self.config.get("Backup", "schedule")
-          self.changes['backup_schedule_day'] = self.config.get("Backup", "day")
-          self.changes['backup_schedule_hour'] = self.config.get("Backup", "hour")
-          self.changes['backup_schedule_minute'] = self.config.get("Backup", "minute")
-          self.changes['backup_schedule_weekday'] = self.config.get("Backup", "weekday")
-          self.db_backup_checkbutton.set_active(int(self.config.get("Backup", "db")))
+            self.config.read(self.CONFIGFILE)
+            self.changes['serverip'] = self.config.get("General", "serverip")
+            self.changes['managed'] = self.config.get("General", "managed")
+            if str.lower(self.changes['managed']) == "true":
+                self.managed_label.set_text("This machine is current in managed mode")
+                self.radio_convert.set_sensitive(False)
+                self.backup_schedule.set_sensitive(False)
+            self.changes['BackupLocation'] = self.config.get("Backup", "storagedir")
+            self.changes['backup_db'] = self.config.get("Backup", "db")
+            self.changes['backup_schedule'] = self.config.get("Backup", "schedule")
+            self.changes['backup_schedule_day'] = self.config.get("Backup", "day")
+            self.changes['backup_schedule_hour'] = self.config.get("Backup", "hour")
+            self.changes['backup_schedule_minute'] = self.config.get("Backup", "minute")
+            self.changes['backup_schedule_weekday'] = self.config.get("Backup", "weekday")
+            self.db_backup_checkbutton.set_active(int(self.config.get("Backup", "db")))
         except:
-          print "Error: Config file not found. Setting defaults"
-          self.changes['serverip'] = "127.0.0.1"
-          self.changes['managed'] = "False"
-          self.changes['BackupLocation'] = "/var/lib/mythtv/bare/"
-          self.changes['backup_db'] = False
-          self.changes['backup_schedule'] = "disabled"
-          self.changes['backup_schedule_day'] = "*"
-          self.changes['backup_schedule_hour'] = "0"
-          self.changes['backup_schedule_minute'] = "00"
-          self.changes['backup_schedule_weekday'] = "*"
+            self.changes['serverip'] = "127.0.0.1"
+            self.changes['managed'] = "False"
+            self.changes['BackupLocation'] = "/var/lib/mythtv/bare/"
+            self.changes['backup_db'] = False
+            self.changes['backup_schedule'] = "disabled"
+            self.changes['backup_schedule_day'] = "*"
+            self.changes['backup_schedule_hour'] = "0"
+            self.changes['backup_schedule_minute'] = "00"
+            self.changes['backup_schedule_weekday'] = "*"
         if not self.query_installed('mythtv-backend-master'):
-          self.backup_db_label.set_text("Database can only be backed up from master backend")
-          self.db_backup_checkbutton.set_sensitive(False)
-          self.db_backup_checkbutton.set_active(False)
+            self.backup_db_label.set_text("Database can only be backed up from master backend")
+            self.db_backup_checkbutton.set_sensitive(False)
+            self.db_backup_checkbutton.set_active(False)
 
     def applyStateToGUI(self):
         """Takes the current state information and sets the GUI
@@ -442,56 +441,56 @@ class MythbuntuBaRePlugin(MCCPlugin):
         for item in reconfigure:
             if item == "Backup Schedule":
                 if reconfigure[item] == False:
-                  self.emit_progress("Removing scheduled job", 50)
-                  if os.path.isfile("/etc/cron.d/mythbuntu-bare"):
-                    os.remove("/etc/cron.d/mythbuntu-bare")
+                    self.emit_progress("Removing scheduled job", 50)
+                    if os.path.isfile("/etc/cron.d/mythbuntu-bare"):
+                        os.remove("/etc/cron.d/mythbuntu-bare")
                 elif reconfigure[item] == True:
-                  CONFIGFILE = "/etc/mythbuntu-bare/mythbuntu-bare-client.conf"
-                  import ConfigParser
-                  config = ConfigParser.ConfigParser()
-                  config.add_section('General')
-                  config.add_section('Backup')
-                  config.set('General', 'serverip', '127.0.0.1')
-                  config.set('General', 'managed', 'false')
-                  config.set('General', 'revision', '1')
-                  for item in reconfigure:
-                    if item == 'Backup Hour':
-                      config.set('Backup', 'hour', reconfigure[item])
-                    if item == 'Backup Minute':
-                      config.set('Backup', 'minute', reconfigure[item])
-                    if item == 'Backup Location':
-                      config.set('Backup', 'storagedir', reconfigure[item])
-                    if item == 'Backup Database':
-                      config.set('Backup', 'db', reconfigure[item])
-                    if item == 'Backup Daily':
-                      config.set('Backup', 'schedule', 'daily')
-                      config.set('Backup', 'day', '*')
-                      config.set('Backup', 'weekday', '*')
-                    if item == 'Backup Weekly':
-                      config.set('Backup', 'schedule', 'weekly')
-                      config.set('Backup', 'day', '*')
-                      config.set('Backup', 'weekday', reconfigure[item])
-                    if item == 'Backup Monthly':
-                      config.set('Backup', 'schedule', 'monthly')
-                      config.set('Backup', 'day', reconfigure[item])
-                      config.set('Backup', 'weekday', '*')
-                  with open(CONFIGFILE, 'wb') as conffile:
-                    config.write(conffile)
-                  sys.path.append("/usr/share/mythbuntu/bare")
-                  from updater import CronUpdater
-                  CronUpdater().generate_cron_schedule()
-            if item == "restore":
+                    CONFIGFILE = "/etc/default/mythbuntu-bare-client.conf"
+                    import ConfigParser
+                    config = ConfigParser.ConfigParser()
+                    config.add_section('General')
+                    config.add_section('Backup')
+                    config.set('General', 'serverip', '127.0.0.1')
+                    config.set('General', 'managed', 'false')
+                    config.set('General', 'revision', '1')
+                    for subitem in reconfigure:
+                        if subitem == 'Backup Hour':
+                            config.set('Backup', 'hour', reconfigure[subitem])
+                        elif subitem == 'Backup Minute':
+                            config.set('Backup', 'minute', reconfigure[subitem])
+                        elif subitem == 'Backup Location':
+                            config.set('Backup', 'storagedir', reconfigure[subitem])
+                        elif subitem == 'Backup Database':
+                            config.set('Backup', 'db', reconfigure[subitem])
+                        elif subitem == 'Backup Daily':
+                            config.set('Backup', 'schedule', 'daily')
+                            config.set('Backup', 'day', '*')
+                            config.set('Backup', 'weekday', '*')
+                        elif subitem == 'Backup Weekly':
+                            config.set('Backup', 'schedule', 'weekly')
+                            config.set('Backup', 'day', '*')
+                            config.set('Backup', 'weekday', reconfigure[subitem])
+                        elif subitem == 'Backup Monthly':
+                            config.set('Backup', 'schedule', 'monthly')
+                            config.set('Backup', 'day', reconfigure[subitem])
+                            config.set('Backup', 'weekday', '*')
+                    with open(CONFIGFILE, 'wb') as conffile:
+                        config.write(conffile)
+                    sys.path.append("/usr/share/mythbuntu/bare")
+                    from updater import CronUpdater
+                    CronUpdater().generate_cron_schedule()
+            elif item == "restore":
                 RESTORE_LOCATION=reconfigure[item]
                 RESTORE_SET=True
-            if item == "restore_db":
+            elif item == "restore_db":
                 RESTORE_DB=reconfigure[item]
                 RESTORE_DB_SET=True
-            if item == "convert":
+            elif item == "convert":
                 PATH=reconfigure[item]
                 try:
-                  shutil.move(PATH, "/etc/mythbuntu-bare/mythbuntu-bare-client.conf")
+                    shutil.move(PATH, "/etc/default/mythbuntu-bare-client.conf")
                 except:
-                  print "Unable to import file"
+                    print "Unable to import file"
         if RESTORE_SET == True and RESTORE_DB_SET == True:
             #TODO
             rj = Thread(target=Restore().restore_job, args=(RESTORE_LOCATION,RESTORE_DB))
