@@ -24,6 +24,7 @@
 from MythbuntuControlCentre.plugin import MCCPlugin
 
 from mythbuntu_common.lirc import LircHandler
+import gtk
 import os
 import subprocess
 import logging
@@ -74,13 +75,19 @@ class RemotePlugin(MCCPlugin):
         for item in ['lirc','mythbuntu-lirc-generator']:
             self.state[item] = self.query_installed(item)
 
+        #TODO, detect smartphone type somehow.
+        self.state['type'] = 'native'
+
         if self.state['lirc']:
+            self.state['type'] = 'lirc'
             if self.count["remote"] is 0:
                 self.lirc=LircHandler()
                 self.populate_lirc()
             #Read in our /etc/lirc/hardware.conf
             self.lirc.read_hardware_conf()
 
+
+
     def applyStateToGUI(self):
         """Takes the current state in formation and sets the GUI"""
 
@@ -108,9 +115,10 @@ class RemotePlugin(MCCPlugin):
             if os.path.exists("/usr/share/lirc/" + type + '/' + dictionary[type + "_lircd_conf"]):
                 conf.select_filename("/usr/share/lirc/" + type + '/' + dictionary[type + "_lircd_conf"])
 
-        if self.state['lirc']:
+        if self.state['type'] == 'lirc':
+            self.smartphone_vbox.set_sensitive(False)
             self.lirc_vbox.set_sensitive(True)
-            self.remote_control_support.set_active(True)
+            self.lirc_support.set_active(True)
             for type in ('remote','transmitter'):
                 dict=self.lirc.get_device_dictionary(type)
                 list=self.builder.get_object(type + '_list')
@@ -121,9 +129,12 @@ class RemotePlugin(MCCPlugin):
 
                 #"Custom" support
                 load_custom(type,dict)
+        elif self.state['type'] == 'native':
+            self.lirc_vbox.set_sensitive(False)
+            self.smartphone_vbox.set_sensitive(False)
         else:
             self.lirc_vbox.set_sensitive(False)
-            self.remote_control_support.set_active(False)
+            self.smartphone_vbox.set_sensitive(True)
 
     def compareState(self):
         """Determines what items have been modified on this plugin"""
@@ -154,11 +165,20 @@ class RemotePlugin(MCCPlugin):
         #Prepare for state capturing
         MCCPlugin.clearParentState(self)
 
-        if self.state['lirc'] != self.remote_control_support.get_active():
-            if self.remote_control_support.get_active():
-                self._markInstall('lirc')
-            else:
-                self._markRemove('lirc')
+        #check for type changes
+        if self.native_support.get_active():
+            radio = 'native'
+        elif self.lirc_support.get_active():
+            radio = 'lirc'
+        else:
+            radio = 'smartphone'
+
+        #figure out if we are installing lirc or removing it
+        if self.state['type'] != radio:
+                if radio == 'lirc' and not self.state['lirc']:
+                    self._markInstall('lirc')
+                elif self.state['lirc']:
+                    self._markRemove('lirc')
 
         if self.state['lirc']:
             for type in ('remote','transmitter'):
@@ -221,10 +241,21 @@ class RemotePlugin(MCCPlugin):
             self.enable_irexec_checkbox.set_active(False)
 
         if widget is not None:
-            #only turn off lirc vbox if it was installed to start
-            if widget.get_name() == "remote_control_support":
-                if self.state['lirc']:
-                    self.lirc_vbox.set_sensitive(widget.get_active())
+            #toggle types on the page
+            if type(widget) is gtk.RadioButton:
+                #they all have callbacks, only use the active one
+                if widget.get_active():
+                    name = widget.get_name()
+                    if name == 'native_support':
+                        self.smartphone_vbox.set_sensitive(False)
+                        self.lirc_vbox.set_sensitive(False)
+                    elif name == 'smartphone_support':
+                        self.smartphone_vbox.set_sensitive(True)
+                        self.lirc_vbox.set_sensitive(False)
+                    #the lirc package needs to be installed to show this
+                    elif self.state['lirc']:
+                        self.smartphone_vbox.set_sensitive(False)
+                        self.lirc_vbox.set_sensitive(True)
 
             #turn on/off IR remote
             elif widget.get_name() == 'remotecontrol':
